==> texinfo-7.1.tar.gz: texinfo-7.1/tp/t/results/raw/raw_expanded_in_style.pl <==
use vars qw(%result_texis %result_texts %result_trees %result_errors 
   %result_indices %result_sectioning %result_nodes %result_menus
   %result_floats %result_converted %result_converted_errors 
   %result_elements %result_directions_text %result_indices_sort_strings);

use utf8;

$result_trees{'raw_expanded_in_style'} = {
  'contents' => [
    {
      'contents' => [
        {
          'contents' => [
            {
              'args' => [
                {
                  'contents' => [
                    {
                      'text' => '
'
                    },
                    {
                      'args' => [
                        {
                          'info' => {
                            'spaces_after_argument' => {
                              'text' => '
'
                            }
                          },
                          'type' => 'block_line_arg'
                        }
                      ],
                      'cmdname' => 'html',
                      'contents' => [
                        {
                          'contents' => [
                            {
                              'text' => 'in html
'
                            }
                          ],
                          'type' => 'rawpreformatted'
                        },
                        {
                          'args' => [
                            {
                              'contents' => [
                                {
                                  'text' => 'html'
                                }
                              ],
                              'info' => {
                                'spaces_after_argument' => {
                                  'text' => '
'
                                }
                              },
                              'type' => 'line_arg'
                            }
                          ],
                          'cmdname' => 'end',
                          'extra' => {
                            'text_arg' => 'html'
                          },
                          'info' => {
                            'spaces_before_argument' => {
                              'text' => ' '
                            }
                          },
                          'source_info' => {
                            'file_name' => '',
                            'line_nr' => 4,
                            'macro' => ''
                          }
                        }
                      ],
                      'source_info' => {
                        'file_name' => '',
                        'line_nr' => 2,
                        'macro' => ''
                      }
                    }
                  ],
                  'type' => 'brace_command_arg'
                }
              ],
              'cmdname' => 'code',
              'source_info' => {
                'file_name' => '',
                'line_nr' => 1,
                'macro' => ''
              }
            }
          ],
          'type' => 'paragraph'
        }
      ],
      'type' => 'before_node_section'
    }
  ],
  'type' => 'document_root'
};

$result_texis{'raw_expanded_in_style'} = '@code{
@html
in html
@end html
}';


$result_texts{'raw_expanded_in_style'} = '
in html
';

$result_errors{'raw_expanded_in_style'} = [];


$result_floats{'raw_expanded_in_style'} = {};



$result_converted{'plaintext'}->{'raw_expanded_in_style'} = '‘ 
in html
’
';


$result_converted{'xml'}->{'raw_expanded_in_style'} = '<para><code>
in html
</code></para>';


$result_converted{'html_text'}->{'raw_expanded_in_style'} = '<p><code class="code">
in html
</code></p>';

1;

==> texinfo-7.2.tar.gz: texinfo-7.2/tp/t/results/raw/raw_expanded_in_style.pl <==
use vars qw(%result_texis %result_texts %result_trees %result_errors 
   %result_indices %result_sectioning %result_nodes %result_menus
   %result_floats %result_converted %result_converted_errors 
   %result_elements %result_directions_text %result_indices_sort_strings);

use utf8;

$result_trees{'raw_expanded_in_style'} = {
  'contents' => [
    {
      'contents' => [
        {
          'contents' => [
            {
              'args' => [
                {
                  'contents' => [
                    {
                      'text' => '
'
                    },
                    {
                      'args' => [
                        {
                          'info' => {
                            'spaces_after_argument' => {
                              'text' => '
'
                            }
                          },
                          'type' => 'block_line_arg'
                        }
                      ],
                      'cmdname' => 'html',
                      'contents' => [
                        {
                          'contents' => [
                            {
                              'text' => 'in html
'
                            }
                          ],
                          'type' => 'rawpreformatted'
                        },
                        {
                          'args' => [
                            {
                              'contents' => [
                                {
                                  'text' => 'html'
                                }
                              ],
                              'info' => {
                                'spaces_after_argument' => {
                                  'text' => '
'
                                }
                              },
                              'type' => 'line_arg'
                            }
                          ],
                          'cmdname' => 'end',
                          'extra' => {
                            'text_arg' => 'html'
                          },
                          'info' => {
                            'spaces_before_argument' => {
                              'text' => ' '
                            }
                          },
                          'source_info' => {
                            'line_nr' => 4
                          }
                        }
                      ],
                      'source_info' => {
                        'line_nr' => 2
                      }
                    }
                  ],
                  'type' => 'brace_container'
                }
              ],
              'cmdname' => 'code',
              'source_info' => {
                'line_nr' => 1
              }
            }
          ],
          'type' => 'paragraph'
        }
      ],
      'type' => 'before_node_section'
    }
  ],
  'type' => 'document_root'
};

$result_texis{'raw_expanded_in_style'} = '@code{
@html
in html
@end html
}';


$result_texts{'raw_expanded_in_style'} = '
in html
';

$result_errors{'raw_expanded_in_style'} = [];


$result_floats{'raw_expanded_in_style'} = {};



$result_converted{'plaintext'}->{'raw_expanded_in_style'} = '‘ in html
’
';


$result_converted{'xml'}->{'raw_expanded_in_style'} = '<para><code>
in html
</code></para>';


$result_converted{'html_text'}->{'raw_expanded_in_style'} = '<p><code class="code">
in html
</code></p>';

1;
